using System;
using System.IO;
using System.Threading.Tasks;
using ELTE.Sudoku.Droid.Persistence;
using ELTE.Sudoku.Persistence;
using Xamarin.Forms;

[assembly: Dependency(typeof(AndroidDataAccess))]
namespace ELTE.Sudoku.Droid.Persistence
{
    /// <summary>
    /// Tic-Tac-Toe adatelrs megvalstsa Android platformra.
    /// </summary>
    public class AndroidDataAccess : ISudokuDataAccess
    {
        /// <summary>
        /// Fjl betltse.
        /// </summary>
        /// <param name="path">Elrsi tvonal.</param>
        /// <returns>A beolvasott mezrtkek.</returns>
        public async Task<SudokuTable> Load(String path)
        {
            // a betlts a szemlyen knyvtrbl trtnik
            String filePath = Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.Personal), path);

            // a fjlmveletet taszk segtsgvel vgezzk (aszinkron mdon)
            String[] values = (await Task.Run(() => File.ReadAllText(filePath))).Split(' ');
            
            Int32 tableSize = Int32.Parse(values[0]);
            Int32 regionSize = Int32.Parse(values[1]);
            SudokuTable table = new SudokuTable(tableSize, regionSize); // ltrehozzuk a tblt

            Int32 valueIndex = 2;
            for (Int32 rowIndex = 0; rowIndex < tableSize; rowIndex++)
            {              
                for (Int32 columnIndex = 0; columnIndex < tableSize; columnIndex++)
                {
                    table.SetValue(rowIndex, columnIndex, Int32.Parse(values[valueIndex]), values[valueIndex] != "0"); // rtkek betltse
                    valueIndex++;
                }
            }

            return table;
        }

        /// <summary>
        /// Fjl mentse.
        /// </summary>
        /// <param name="path">Elrsi tvonal.</param>
        /// <param name="table">A fjlba kirand jtktbla.</param>
        public async Task Save(String path, SudokuTable table)
        {
            String text = table.Size.ToString() + " " + table.RegionSize.ToString(); // mret

            for (Int32 i = 0; i < table.Size; i++)
            {
                for (Int32 j = 0; j < table.Size; j++)
                {
                    text += table[i, j] + " "; // mezrtkek
                }
            }

            // fjl ltrehozsa
            String filePath = Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.Personal), path);

            // kirs (aszinkron mdon)
            await Task.Run(() => File.WriteAllText(filePath, text));
        }
    }
}